==> osmium-tool_1.0.1.orig.tar.gz: osmium-tool-1.0.1/src/command_apply_changes.hpp <==
#ifndef COMMAND_APPLY_CHANGES_HPP
#define COMMAND_APPLY_CHANGES_HPP

/*

Osmium -- OpenStreetMap data manipulation command line tool
http://osmcode.org/osmium

Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include <string>
#include <vector>

#include <osmium/io/file.hpp>
#include <osmium/io/overwrite.hpp>

#include "osmc.hpp"

class CommandApplyChanges : public Command {

    std::string m_input_filename = "-"; // default: stdin
    std::string m_output_filename = "-"; // default: stdout
    std::vector<std::string> m_change_filenames;

    std::string m_input_format;
    std::string m_output_format;

    osmium::io::overwrite m_output_overwrite = osmium::io::overwrite::no;
    bool m_simplify_change = false;
    bool m_remove_deleted = false;

    osmium::io::File m_output_file;

public:

    CommandApplyChanges() = default;

    bool setup(const std::vector<std::string>& arguments) override final;

    bool run() override final;

}; // class CommandApplyChanges


#endif // COMMAND_APPLY_CHANGES_HPP

==> osmium-tool_1.5.0.orig.tar.gz: osmium-tool-1.5.0/src/command_apply_changes.hpp <==
#ifndef COMMAND_APPLY_CHANGES_HPP
#define COMMAND_APPLY_CHANGES_HPP

/*

Osmium -- OpenStreetMap data manipulation command line tool
http://osmcode.org/osmium-tool/

Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

*/

#include <string>
#include <vector>

#include "cmd.hpp" // IWYU pragma: export

class CommandApplyChanges : public Command, public with_single_osm_input, public with_osm_output {

    std::vector<std::string> m_change_filenames;

    bool m_with_history = false;

public:

    CommandApplyChanges() = default;

    bool setup(const std::vector<std::string>& arguments) override final;

    void show_arguments() override final;

    bool run() override final;

    const char* name() const noexcept override final {
        return "apply-changes";
    }

    const char* synopsis() const noexcept override final {
        return "osmium apply-changes [OPTIONS] OSM-FILE OSM-CHANGE-FILE...";
    }

}; // class CommandApplyChanges


#endif // COMMAND_APPLY_CHANGES_HPP
